MuMoT: Multiscale Modelling Tool
================================

MuMoT was developed at the University of Sheffield as part of the `DiODe <http://diode.group.shef.ac.uk/>`__ project.

MuMoT (Multiscale Modelling Tool) is a tool designed to allow sophisticated mathematical modelling and analysis, without writing equations
- the class of models that can be represented is broad, ranging from chemical reaction kinetics to demography and collective behaviour
- by using a web-based interactive interface with minimal coding, rapid development and exploration of models is facilitated
- the tool may also be particularly useful for pedagogical demonstrations

.. todo:: Add general overview (inc graphic?)

.. toctree::
   :maxdepth: 2
   :hidden:

   self

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   getting_started
   install
   about
   faq
   development
   api
